==> gpflib-1.1.5.tar.gz: gpflib-1.1.5/gpflib/gpf_Test.py <==
from ast import UAdd
from email.header import Header
from inspect import isawaitable
import json
import re
import os,glob
from tkinter import colorchooser
from gpflib import GPF
import requests
import jieba
import gpflib

def PrintRelation(gpf):
    Relations=gpf.GetRelations()
    for R in Relations:
        Relation=gpf.GetWord(R["U1"])+" "+gpf.GetWord(R["U2"])+"("+R["R"]+")"
        KVs=gpf.GetRelationKVs(R["U1"],R["U2"],R["R"])
        Info=""
        for k in KVs:
            Val=" ".join(KVs[k])
            if len(KVs[k]) > 1:
                Info=Info+k+"=["+Val+"] "
            else:
                Info=Info+k+"="+Val+" "
            print("=>"+Relation)
        if Info != "":
	        print("KV:"+Info)


def PrintUnit(gpf,Type=""):
    if Type =="":
        Type="Type=Chunk|Type=Word|Type=Phrase|Type=Char"	
    GridInfo=gpf.GetGrid()
    for Col in GridInfo:
        for Unit in Col:
            if gpf.IsUnit(Unit,Type):
                Info=""
                KVs=gpf.GetUnitKVs(Unit)
                print("=>",gpf.GetWord(Unit))
                for K in KVs:
                    Val=" ".join(KVs[K])
                    print(K,"=",Val)



def Test_Grid():
    gpf = GPF("config.txt")
    Line='{"Type": "Chunk", "Units": ["瑞士球员塞费罗维奇", "率先", "破门", "，", "沙其理", "梅开二度", "。"], "POS": ["NP", "XP", "VP", "w", "NP", "VP", "w"], "Groups": [{"HeadID": 1, "Group": [{"Role": "sbj", "SubID": 0}]}, {"HeadID": 2, "Group": [{"Role": "sbj", "SubID": 0}]}, {"HeadID": 5, "Group": [{"Role": "sbj", "SubID": 4}]}],"ST":"dep"}'
    gpf.AddGridJS(Line)
    Grid = gpf.GetGrid()
    for C in Grid:
        for U in C:
            print(U,gpf.GetWord(U))
            
    KV = gpf.GetGridKVs("")
    for K in KV:
        for V in KV[K]:
            print(K,V)

def Test_JSON():
    Line= """
    {"Words": ["瑞士", "率先", "破门", "，", "沙其理", "梅开二度", "。"], 
    "Tags": ["ns", "d", "v", "w", "nr", "i", "w"], 
    "Relations": [{"U1": 2, "U2":0,"R":"A0","KV":"KV1"},
    {"U1": 2, "U2":1,"R":"Mod","KV":"KV2"},
    {"U1": 5, "U2":4,"R":"A0","KV":"KV3"}]} """
    gpf = GPF()
    
    json_data = json.loads(Line)
    Sentence="".join(json_data["Words"])
    gpf.SetGridText(Sentence)
    Units=[]
    Col=0
    for i in range(len(json_data["Words"])):
        Col=Col+len(json_data["Words"][i])
        print(json_data["Words"][i],Col-1)
        Unit=gpf.AddUnit(Col-1,json_data["Words"][i])
        gpf.AddUnitKV(Unit,"POS",json_data["Tags"][i])
        Units.append(Unit)
        
    for i in  range(len(json_data["Relations"])):
        U1=Units[json_data["Relations"][i]["U1"]]
        U2=Units[json_data["Relations"][i]["U2"]]
        R=json_data["Relations"][i]["R"]
        KV=json_data["Relations"][i]["KV"]
        gpf.AddRelation(U1,U2,R)
        gpf.AddRelationKV(U1,U2,R,"KV",KV)

    GridInfo=gpf.GetGrid()
    for C in GridInfo:
        for U in  C:
            print("=>",gpf.GetWord(U))
	
    Rs = gpf.GetRelations("")
    for R in Rs:
        print(gpf.GetWord(R["U1"]),gpf.GetWord(R["U2"]),R["R"])
    print(gpf.GetText(0,-1))


def Test_TermInfo():
    gpf = GPF()
    Line="称一种无线通讯技术为蓝牙"
    gpf.SetGridText(Line)
    gpf.CallTable("Segment_Term")
    gpf.CallFSA("Term")
    Units=gpf.GetUnit("Tag=Term")
    for i in range(len(Units)):
        print(gpf.GetWord(Units[i]))     

def Idx_GPF(Name,Path="./data"):
    for file in glob.glob(Path):
        if os.path.isfile(file):
            os.remove(file)

    gpf = GPF(Path)
    FSA="./Examples/"+Name+"/GPF.fsa"
    if os.path.exists(FSA):
        gpf.IndexFSA(FSA)
    Table="./Examples/"+Name+"/GPF.tab"
    if os.path.exists(Table):
        gpf.IndexTable(Table)
   
def Test_Time():
    Line="星期日下午我去图书馆"
    gpf = GPF()
    gpf.SetGridText(Line)
    gpf.CallTable("Time_Entry")
    gpf.CallFSA("Time")
    Us=gpf.GetUnit("Tag=Time")
    for U in Us:
        print(gpf.GetWord(U))


def Test_DupWord():
    Sent="李明回头看了一看。"
    gpf = GPF()
    Segment=gpf.Parse(Sent,Structure="Segment")
    gpf.AddGridJS(Segment)
    gpf.CallFSA("DupWord")
    Units=gpf.GetUnit("Tag=DupWord")
    for i in range(len(Units)):
        print(gpf.GetWord(Units[i]))

def Test_Merge():
    Line = "下半场的38分钟，李明攻入第1个球，成功将比分扳平至2-1。"
    gpf = GPF()
    gpf.SetGridText(Line)
    depseg_struct = gpf.Parse(Line, "depseg")
    gpf.AddGridJS(depseg_struct)
    gpf.CallTable("Merge_Dict")
    gpf.CallFSA("Merge")
    phrase_units = gpf.GetUnit("Tag=MatchTime|Tag=Order|Tag=MatchScore")
    for i in range(len(phrase_units)):
        print(gpf.GetWord(phrase_units[i]))

def Test_Mood():
    Sent="李明非常不喜欢他"
    gpf = GPF()
    gpf.SetGridText(Sent)
    DepStruct=gpf.Parse(gpf.GetText(),Structure="Dependency")
    gpf.AddGridJS(DepStruct)
    Seg=gpf.Parse(gpf.GetText(),Structure="Segment")
    gpf.AddGridJS(Seg)
    gpf.CallTable("Tab_Mod")
    gpf.CallFSA("Mod2Head")
    gpf.CallFSA("Mod2Prd")
    Logs=gpf.GetLog()
    for log in Logs:
        print(log)
    Units=gpf.GetUnit("Tag=Mood")
    for i in range(len(Units)):
        print(gpf.GetWord(Units[i]))


def Test_WSD():
    gpf=GPF()
    Sentence="这个苹果很甜呀"
    gpf.SetTable("Dict_Info")
    gpf.SetGridText(Sentence)
    Segment=gpf.Parse(gpf.GetText(),Structure="Segment")
    gpf.AddGridJS(Segment)
    Units=gpf.GetUnit("Sem=*")
    for i in range(len(Units)):
        Sems=gpf.GetUnitKVs(Units[i],"Sem")
        MaxScore=-10
        WS=""
        for j in range(len(Sems)):
            gpf.CallFSA("WSD","Sem="+Sems[j])
            Score=gpf.GetUnitKVs(Units[i],"Sem_"+Sems[j])
            if len(Score) != 0:
                Score=int(Score[0])
            else:
                Score=0
            if MaxScore < Score:
                MaxScore = Score
                WS=Sems[j]
        if WS != "":
            gpf.AddUnitKV(Units[i],"Sense",WS)
    Units=gpf.GetUnit("Sense=*")
    for i in range(len(Units)):
        WS,=gpf.GetUnitKVs(Units[i],"Sense")
        print(gpf.GetWord(Units[i]),WS)

def Test_SepWord(Type):
    Sent="李明把守的大门被他破了"
    gpf=GPF()
    gpf.SetGridText(Sent)
    DepStruct=gpf.Parse(gpf.GetText(),Structure="Dependency")
    gpf.AddGridJS(DepStruct)
    Seg=gpf.Parse(gpf.GetText(),Structure="Segment")
    gpf.AddGridJS(Seg)
    gpf.CallTable("Sep_V")
    if Type == 1:
        gpf.CallFSA("SepV1")
    else:
        gpf.CallFSA("SepV2")
    Units=gpf.GetUnit("Tag=SepWord")
    for  Unit in Units:
        print(gpf.GetWord(Unit))

def Test_CoEvent():
    Sentence="淘气的孩子打碎了一个花瓶。"
    gpf=GPF()
    gpf.SetGridText(Sentence)
    DepStruct=gpf.Parse(gpf.GetText(),Structure="Dependency")
    gpf.AddGridJS(DepStruct)
    Seg=gpf.Parse(gpf.GetText(),Structure="Segment")
    gpf.AddGridJS(Seg)
    gpf.CallTable("Co_Event")
    gpf.CallFSA("CoEvent")
    PrintUnit(gpf)

def Test_Main():
    Idx_GPF("CoEvent")
    Test_CoEvent()

def BCC_Corpus1():
    gpf=GPF()
    IN=open("./Examples/BuildBCC/Corpus.txt","r")    
    Out=open("./Examples/BuildBCC/treebank.txt","w")
    Num=0
    for Line in IN:
        Num+=1;
        Tree=gpf.Parse(Line.strip(),Structure="Tree")
        try:
            Ret=json.loads(Tree.replace('\\','\\\\'),strict=True)
        except:
            continue
        if Ret.get("Units") and len(Ret["Units"]) >0:
            print(json.loads(Tree)["Units"][0],file=Out)
        if Num%50 == 0:
            print("processing:",Num,end="\r")
            
    IN.close()
    Out.close()

def BCC_Corpus2():
    CorpusIn="./Examples/BuildBCC/treebank.txt"
    CorpusOut="./Examples/BuildBCC/treebankEx.txt"
    IN=open(CorpusIn,"r")    
    Out=open(CorpusOut,"w")
    Num=0
    No=0
    for Line in IN:
        Line=Line.strip()
        if Num%100 == 0:
            print("Table %dParts"%No,file=Out)
            print("#Global ID=%d"%No,file=Out)
            No+=1
        Num+=1;
        print("Item:%s"%Line,file=Out)
    IN.close()
    Out.close()

    

def BCC_Lua2():
    gpf = GPF()
    Query='''
Handle0=GetAS("$NP-SBJ","","","","","~","","","","0,1")
Handle1=GetAS("击>","打击")
Handle3=JoinAS(Handle0,Handle1,"*")
Handle4=Freq(Handle3,"$1")
Ret=Output(Handle4,1000)
return Ret'''
    Ret=gpf.BCC(Query,Service="BCC")
    print(Ret)
    

def Test():
    gpf = GPF()
    Files=["D:/Xunendong/GPF/Src/pysetup/gpflib/Examples/BuildBCC/treebankEx.txt"]
    Ret=gpf.IndexBCC(Files)
    

def Test2():
    gpf = GPF()
    Ret=gpf.GetTable()
    for I in Ret:
        print(I)
        Items=gpf.GetTableItem(I)
        for It in Items:
            KV=gpf.GetTableItemKV(I,It)
            print(KV)
            for K,V in KV.items():
                print(K,"".join(V))    
        
def Test3():
    gpf = GPF()
    In=open("./Examples/BuildBCC/Corpus.txt","r")
    Num=0
    for S in In:
        Ret=gpf.Parse(S.strip(),Structure="Chunk")
        if Num%500 == 0:
            print(Num,Ret)
        Num+=1 
    In.close()

           
def Test5():
    In=open("./Examples/BuildBCC/Corpus.txt","r")
    Num=0
    for S in In:
        Ret=jieba.lcut(S)
        if Num%2000 == 0:
            print(Num,Ret)
        Num+=1 
    In.close()

def Test6():
    gpf = GPF()   
    In=open("word.txt","r",encoding="utf-8")
    for L in In:
        L=L.strip()
        Array=L.split("\t")
        if len(Array) > 1 :
            Ret=gpf.BCC(Array[0],Command="Freq",Service="BCC")
            print(Ret)
            
    In.close()

def Test7():
    gpf = GPF()   
    Ret=gpf.BCC("(a)的",Command="Freq",Target="$1",WinSize=30,ContextNum=5)
    print(Ret)

def Parse1():
    Line="我们大家今天下午在邵逸夫操场集合"
    gpf=GPF()
    Ret=gpf.Parse(Line,Structure="Tree")
    gpf.AddGridJS(Ret)
    gpf.Show()

def UnitInfo(Unit):
    Ret=Unit
    Ret=Ret.replace("(","U")
    Ret=Ret.replace(")","")
    Ret=Ret.replace(",","_")
    return Ret

def DrawGrid():
    Line="我们大家今天下午在邵逸夫操场集合"
    gpf=GPF()
    Ret=gpf.Parse(Line,Structure="Tree")
    gpf.AddGridJS(Ret)
    gpf.Show()


DrawGrid()

==> gpflib-1.1.6.tar.gz: gpflib-1.1.6/gpflib/gpf_Test.py <==
from ast import UAdd
from email.header import Header
from inspect import isawaitable
import json
import re
import os,glob
from tkinter import colorchooser
from gpflib import GPF
import requests
import jieba
import gpflib

def PrintRelation(gpf):
    Relations=gpf.GetRelations()
    for R in Relations:
        Relation=gpf.GetWord(R["U1"])+" "+gpf.GetWord(R["U2"])+"("+R["R"]+")"
        KVs=gpf.GetRelationKVs(R["U1"],R["U2"],R["R"])
        Info=""
        for k in KVs:
            Val=" ".join(KVs[k])
            if len(KVs[k]) > 1:
                Info=Info+k+"=["+Val+"] "
            else:
                Info=Info+k+"="+Val+" "
            print("=>"+Relation)
        if Info != "":
	        print("KV:"+Info)


def PrintUnit(gpf,Type=""):
    if Type =="":
        Type="Type=Chunk|Type=Word|Type=Phrase|Type=Char"	
    GridInfo=gpf.GetGrid()
    for Col in GridInfo:
        for Unit in Col:
            if gpf.IsUnit(Unit,Type):
                Info=""
                KVs=gpf.GetUnitKVs(Unit)
                print("=>",gpf.GetWord(Unit))
                for K in KVs:
                    Val=" ".join(KVs[K])
                    print(K,"=",Val)



def Test_Grid():
    gpf = GPF("config.txt")
    Line='{"Type": "Chunk", "Units": ["瑞士球员塞费罗维奇", "率先", "破门", "，", "沙其理", "梅开二度", "。"], "POS": ["NP", "XP", "VP", "w", "NP", "VP", "w"], "Groups": [{"HeadID": 1, "Group": [{"Role": "sbj", "SubID": 0}]}, {"HeadID": 2, "Group": [{"Role": "sbj", "SubID": 0}]}, {"HeadID": 5, "Group": [{"Role": "sbj", "SubID": 4}]}],"ST":"dep"}'
    gpf.AddGridJS(Line)
    Grid = gpf.GetGrid()
    for C in Grid:
        for U in C:
            print(U,gpf.GetWord(U))
            
    KV = gpf.GetGridKVs("")
    for K in KV:
        for V in KV[K]:
            print(K,V)

def Test_JSON():
    Line= """
    {"Words": ["瑞士", "率先", "破门", "，", "沙其理", "梅开二度", "。"], 
    "Tags": ["ns", "d", "v", "w", "nr", "i", "w"], 
    "Relations": [{"U1": 2, "U2":0,"R":"A0","KV":"KV1"},
    {"U1": 2, "U2":1,"R":"Mod","KV":"KV2"},
    {"U1": 5, "U2":4,"R":"A0","KV":"KV3"}]} """
    gpf = GPF()
    
    json_data = json.loads(Line)
    Sentence="".join(json_data["Words"])
    gpf.SetGridText(Sentence)
    Units=[]
    Col=0
    for i in range(len(json_data["Words"])):
        Col=Col+len(json_data["Words"][i])
        print(json_data["Words"][i],Col-1)
        Unit=gpf.AddUnit(Col-1,json_data["Words"][i])
        gpf.AddUnitKV(Unit,"POS",json_data["Tags"][i])
        Units.append(Unit)
        
    for i in  range(len(json_data["Relations"])):
        U1=Units[json_data["Relations"][i]["U1"]]
        U2=Units[json_data["Relations"][i]["U2"]]
        R=json_data["Relations"][i]["R"]
        KV=json_data["Relations"][i]["KV"]
        gpf.AddRelation(U1,U2,R)
        gpf.AddRelationKV(U1,U2,R,"KV",KV)

    GridInfo=gpf.GetGrid()
    for C in GridInfo:
        for U in  C:
            print("=>",gpf.GetWord(U))
	
    Rs = gpf.GetRelations("")
    for R in Rs:
        print(gpf.GetWord(R["U1"]),gpf.GetWord(R["U2"]),R["R"])
    print(gpf.GetText(0,-1))


def Test_TermInfo():
    gpf = GPF()
    Line="称一种无线通讯技术为蓝牙"
    gpf.SetGridText(Line)
    gpf.CallTable("Segment_Term")
    gpf.CallFSA("Term")
    Units=gpf.GetUnit("Tag=Term")
    for i in range(len(Units)):
        print(gpf.GetWord(Units[i]))     

def Idx_GPF(Name,Path="./data"):
    for file in glob.glob(Path):
        if os.path.isfile(file):
            os.remove(file)

    gpf = GPF(Path)
    FSA="./Examples/"+Name+"/GPF.fsa"
    if os.path.exists(FSA):
        gpf.IndexFSA(FSA)
    Table="./Examples/"+Name+"/GPF.tab"
    if os.path.exists(Table):
        gpf.IndexTable(Table)
   
def Test_Time():
    Line="星期日下午我去图书馆"
    gpf = GPF()
    gpf.SetGridText(Line)
    gpf.CallTable("Time_Entry")
    gpf.CallFSA("Time")
    Us=gpf.GetUnit("Tag=Time")
    for U in Us:
        print(gpf.GetWord(U))


def Test_DupWord():
    Sent="李明回头看了一看。"
    gpf = GPF()
    Segment=gpf.Parse(Sent,Structure="Segment")
    gpf.AddGridJS(Segment)
    gpf.CallFSA("DupWord")
    Units=gpf.GetUnit("Tag=DupWord")
    for i in range(len(Units)):
        print(gpf.GetWord(Units[i]))

def Test_Merge():
    Line = "下半场的38分钟，李明攻入第1个球，成功将比分扳平至2-1。"
    gpf = GPF()
    gpf.SetGridText(Line)
    depseg_struct = gpf.Parse(Line, "depseg")
    gpf.AddGridJS(depseg_struct)
    gpf.CallTable("Merge_Dict")
    gpf.CallFSA("Merge")
    phrase_units = gpf.GetUnit("Tag=MatchTime|Tag=Order|Tag=MatchScore")
    for i in range(len(phrase_units)):
        print(gpf.GetWord(phrase_units[i]))

def Test_Mood():
    Sent="李明非常不喜欢他"
    gpf = GPF()
    gpf.SetGridText(Sent)
    DepStruct=gpf.Parse(gpf.GetText(),Structure="Dependency")
    gpf.AddGridJS(DepStruct)
    Seg=gpf.Parse(gpf.GetText(),Structure="Segment")
    gpf.AddGridJS(Seg)
    gpf.CallTable("Tab_Mod")
    gpf.CallFSA("Mod2Head")
    gpf.CallFSA("Mod2Prd")
    Logs=gpf.GetLog()
    for log in Logs:
        print(log)
    Units=gpf.GetUnit("Tag=Mood")
    for i in range(len(Units)):
        print(gpf.GetWord(Units[i]))


def Test_WSD():
    gpf=GPF()
    Sentence="这个苹果很甜呀"
    gpf.SetTable("Dict_Info")
    gpf.SetGridText(Sentence)
    Segment=gpf.Parse(gpf.GetText(),Structure="Segment")
    gpf.AddGridJS(Segment)
    Units=gpf.GetUnit("Sem=*")
    for i in range(len(Units)):
        Sems=gpf.GetUnitKVs(Units[i],"Sem")
        MaxScore=-10
        WS=""
        for j in range(len(Sems)):
            gpf.CallFSA("WSD","Sem="+Sems[j])
            Score=gpf.GetUnitKVs(Units[i],"Sem_"+Sems[j])
            if len(Score) != 0:
                Score=int(Score[0])
            else:
                Score=0
            if MaxScore < Score:
                MaxScore = Score
                WS=Sems[j]
        if WS != "":
            gpf.AddUnitKV(Units[i],"Sense",WS)
    Units=gpf.GetUnit("Sense=*")
    for i in range(len(Units)):
        WS,=gpf.GetUnitKVs(Units[i],"Sense")
        print(gpf.GetWord(Units[i]),WS)

def Test_SepWord(Type):
    Sent="李明把守的大门被他破了"
    gpf=GPF()
    gpf.SetGridText(Sent)
    DepStruct=gpf.Parse(gpf.GetText(),Structure="Dependency")
    gpf.AddGridJS(DepStruct)
    Seg=gpf.Parse(gpf.GetText(),Structure="Segment")
    gpf.AddGridJS(Seg)
    gpf.CallTable("Sep_V")
    if Type == 1:
        gpf.CallFSA("SepV1")
    else:
        gpf.CallFSA("SepV2")
    Units=gpf.GetUnit("Tag=SepWord")
    for  Unit in Units:
        print(gpf.GetWord(Unit))

def Test_CoEvent():
    Sentence="淘气的孩子打碎了一个花瓶。"
    gpf=GPF()
    gpf.SetGridText(Sentence)
    DepStruct=gpf.Parse(gpf.GetText(),Structure="Dependency")
    gpf.AddGridJS(DepStruct)
    Seg=gpf.Parse(gpf.GetText(),Structure="Segment")
    gpf.AddGridJS(Seg)
    gpf.CallTable("Co_Event")
    gpf.CallFSA("CoEvent")
    PrintUnit(gpf)

def Test_Main():
    Idx_GPF("CoEvent")
    Test_CoEvent()

def BCC_Corpus1():
    gpf=GPF()
    IN=open("./Examples/BuildBCC/Corpus.txt","r")    
    Out=open("./Examples/BuildBCC/treebank.txt","w")
    Num=0
    for Line in IN:
        Num+=1;
        Tree=gpf.Parse(Line.strip(),Structure="Tree")
        try:
            Ret=json.loads(Tree.replace('\\','\\\\'),strict=True)
        except:
            continue
        if Ret.get("Units") and len(Ret["Units"]) >0:
            print(json.loads(Tree)["Units"][0],file=Out)
        if Num%50 == 0:
            print("processing:",Num,end="\r")
            
    IN.close()
    Out.close()

def BCC_Corpus2():
    CorpusIn="./Examples/BuildBCC/treebank.txt"
    CorpusOut="./Examples/BuildBCC/treebankEx.txt"
    IN=open(CorpusIn,"r")    
    Out=open(CorpusOut,"w")
    Num=0
    No=0
    for Line in IN:
        Line=Line.strip()
        if Num%100 == 0:
            print("Table %dParts"%No,file=Out)
            print("#Global ID=%d"%No,file=Out)
            No+=1
        Num+=1;
        print("Item:%s"%Line,file=Out)
    IN.close()
    Out.close()

    

def BCC_Lua2():
    gpf = GPF()
    Query='''
Handle0=GetAS("$NP-SBJ","","","","","~","","","","0,1")
Handle1=GetAS("击>","打击")
Handle3=JoinAS(Handle0,Handle1,"*")
Handle4=Freq(Handle3,"$1")
Ret=Output(Handle4,1000)
return Ret'''
    Ret=gpf.BCC(Query,Service="BCC")
    print(Ret)
    

def Test():
    gpf = GPF()
    Files=["D:/Xunendong/GPF/Src/pysetup/gpflib/Examples/BuildBCC/CiDian_tree_info.txt"]
    Ret=gpf.IndexBCC(Files)
    

def Test2():
    gpf = GPF()
    Ret=gpf.GetTable()
    for I in Ret:
        print(I)
        Items=gpf.GetTableItem(I)
        for It in Items:
            KV=gpf.GetTableItemKV(I,It)
            print(KV)
            for K,V in KV.items():
                print(K,"".join(V))    
        
def Test3():
    gpf = GPF()
    In=open("./Examples/BuildBCC/Corpus.txt","r")
    Num=0
    for S in In:
        Ret=gpf.Parse(S.strip(),Structure="Chunk")
        if Num%500 == 0:
            print(Num,Ret)
        Num+=1 
    In.close()

           
def Test5():
    In=open("./Examples/BuildBCC/Corpus.txt","r")
    Num=0
    for S in In:
        Ret=jieba.lcut(S)
        if Num%2000 == 0:
            print(Num,Ret)
        Num+=1 
    In.close()

def Test6():
    gpf = GPF()   
    In=open("word.txt","r",encoding="utf-8")
    for L in In:
        L=L.strip()
        Array=L.split("\t")
        if len(Array) > 1 :
            Ret=gpf.BCC(Array[0],Command="Freq",Service="BCC")
            print(Ret)
            
    In.close()

def Test7():
    gpf = GPF()   
    Ret=gpf.BCC("(a)的",Command="Freq",Target="$1",WinSize=30,ContextNum=5)
    print(Ret)

def Parse1():
    Line="我们大家今天下午在邵逸夫操场集合"
    gpf=GPF()
    Ret=gpf.Parse(Line,Structure="Tree")
    gpf.AddGridJS(Ret)
    gpf.Show()

def UnitInfo(Unit):
    Ret=Unit
    Ret=Ret.replace("(","U")
    Ret=Ret.replace(")","")
    Ret=Ret.replace(",","_")
    return Ret

def DrawGrid():
    Line="我们大家今天下午在邵逸夫操场集合"
    gpf=GPF()
    Ret=gpf.Parse(Line,Structure="Tree")
    gpf.AddGridJS(Ret)
    gpf.Show()

def Test11():
    gpf = GPF()
    Ret=gpf.BCC("家庭",Command="Context",WinSize=1)
    print(Ret)    

Test11()
